@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 from subprocess import run
 from pathlib import Path
+from shlex import split
 
 
 @dataclass
@@ -8,12 +9,13 @@ class XMaker:
     xmake: str = "xmake"
     root: str = "."
     out: str = "."
+    command: str = ""
 
     def __post_init__(self):
         self.output = str(Path(self.root) / self.out)
 
     def config(self):
-        run([self.xmake, "config", "-P", self.root])
+        run([self.xmake, "config", "-P", self.root] + split(self.command))
 
     def build(self):
         run([self.xmake, "-P", self.root, "--verbose"])
